<p align="center">
    <a href="https://sylius.com" target="_blank">
        <img src="https://demo.sylius.com/assets/shop/img/logo.png" />
    </a>
</p>

<p align="center">
    <a href="https://sylius.com" target="_blank">
        <img src="https://www.dedi-agency.com/wp-content/uploads/2014/05/Dedi_logo_HD.png" />
    </a>
</p>

<h1 align="center">Dedi Translation Plugin</h1>

<p align="center">Translation plugin for Sylius. Based on [Lexik Translation Bundle](https://github.com/lexik/LexikTranslationBundle) </p>

# Use

### Require the plugin with composer :

```bash
composer require dedi/dedi-translation-plugin
```

### Import configuration :
```yaml
# config/packages/dedi_translation_plugin.yaml
imports:
    # ...
    - { resource: "@DediTranslationPlugin/Resources/config/config.yml" }
```

### Import routing :
```yaml
# config/routes.yaml
    # ...
    dedi_sylius_translation_shop:
        resource: "@DediSyliusTranslationPlugin/Resources/config/shop_routing.yml"
        prefix: /{_locale}
        requirements:
            _locale: ^[a-z]{2}(?:_[A-Z]{2})?$
    
    dedi_sylius_translation_admin:
        resource: "@DediSyliusTranslationPlugin/Resources/config/admin_routing.yml"
        prefix: /admin
    # ...
```

### Add plugin class to your bundles.php :
```php
<?php
$bundles = [
    // ...
    Dedi\SyliusTranslationPlugin\DediSyliusTranslationPlugin::class => ['all' => true],
    Lexik\Bundle\TranslationBundle\LexikTranslationBundle::class => ['all' => true],
    // ...
];
```

### Add your locales to the config
```yaml
# config/packages/_sylius.yaml
lexik_translation:
    fallback_locale: [fr, en]
    managed_locales: [fr, en]
```

### Copy templates to override LexikTranslationBundle template
```bash
cp -R ./vendor/dedi/sylius-translation-plugin/src/Resources/views/templates ./
```

### (Optionnal) Add the command to automatically merge translations on install
```json
// composer.json
{
  ...
  "scripts": {
    "auto-scripts": {
      ...
      "lexik:translations:import --merge": "symfony-cmd",
      ...
    }
  }
}
```

### Update your database :

```bash
$ bin/console doctrine:migrations:diff
$ bin/console doctrine:migrations:migrate
```

### Install assets :

```bash
$ bin/console assets:install
$ bin/console sylius:theme:assets:install
```

### Clear cache :

```bash
$ bin/console cache:clear
```

# Contribute

## Documentation

For a comprehensive guide on Sylius Plugins development please go to Sylius documentation,
there you will find the <a href="https://docs.sylius.com/en/latest/plugin-development-guide/index.html">Plugin Development Guide</a>, that is full of examples.

## Quickstart Installation

```bash
$ make start
$ make db-create
$ make db-update
$ make fixtures
$ make assets
$ make build
```

## Usage

### Running plugin tests

  - PHPUnit

    ```bash
    $ vendor/bin/phpunit
    ```

  - PHPSpec

    ```bash
    $ vendor/bin/phpspec run
    ```

  - Behat (non-JS scenarios)

    ```bash
    $ vendor/bin/behat --tags="~@javascript"
    ```

  - Behat (JS scenarios)
 
    1. Download [Chromedriver](https://sites.google.com/a/chromium.org/chromedriver/)
    
    2. Download [Selenium Standalone Server](https://www.seleniumhq.org/download/).
    
    2. Run Selenium server with previously downloaded Chromedriver:
    
        ```bash
        $ java -Dwebdriver.chrome.driver=chromedriver -jar selenium-server-standalone.jar
        ```
        
    3. Run test application's webserver on `localhost:8080`:
    
        ```bash
        $ (cd tests/Application && bin/console server:run localhost:8080 -d public -e test)
        ```
    
    4. Run Behat:
    
        ```bash
        $ vendor/bin/behat --tags="@javascript"
        ```

### Opening Sylius with your plugin

- Using `test` environment:

    ```bash
    $ (cd tests/Application && bin/console sylius:fixtures:load -e test)
    $ (cd tests/Application && bin/console server:run -d public -e test)
    ```
    
- Using `dev` environment:

    ```bash
    $ (cd tests/Application && bin/console sylius:fixtures:load -e dev)
    $ (cd tests/Application && bin/console server:run -d public -e dev)
    ```
